package agent

import (
	"context"
	"tydata-server/common/ctxdata"
	"tydata-server/common/xerr"

	"github.com/jinzhu/copier"
	"github.com/pkg/errors"

	"tydata-server/app/main/api/internal/svc"
	"tydata-server/app/main/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetAgentAuditStatusLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetAgentAuditStatusLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetAgentAuditStatusLogic {
	return &GetAgentAuditStatusLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetAgentAuditStatusLogic) GetAgentAuditStatus() (resp *types.AgentAuditStatusResp, err error) {
	userID, err := ctxdata.GetUidFromCtx(l.ctx)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "获取代理审核信息, %v", err)
	}

	// 使用SelectBuilder构建查询，查找符合user_id的记录并按创建时间降序排序获取最新一条
	builder := l.svcCtx.AgentAuditModel.SelectBuilder().Where("user_id = ?", userID).OrderBy("create_time DESC").Limit(1)
	agentAuditList, err := l.svcCtx.AgentAuditModel.FindAll(l.ctx, builder, "")
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "获取代理审核信息, %v", err)
	}

	if len(agentAuditList) == 0 {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "未找到代理审核信息")
	}

	agentAuditModel := agentAuditList[0]
	var agentAuditStautsResp types.AgentAuditStatusResp
	copier.Copy(&agentAuditStautsResp, agentAuditModel)
	return &agentAuditStautsResp, nil
}
